@@ -18,7 +18,6 @@ import click
 
 from flaskstarter import __version__
 
-from flaskstarter.tools.requirements import add_support_to
 from flaskstarter.tools.templating import get_template
 
 
@@ -36,8 +35,8 @@ def init(name: str):
     """Creates the project's source tree.
 
     Args:
-        name (str): Project's main package's name to create. If it's a dot, will use current
-                    directory as project's name.
+
+      - name (str): Project's main package's name to create. If it's a dot, will use current directory as project's name.
 
     """
     # All directories and basic python files are created here
@@ -49,15 +48,11 @@ def init(name: str):
     try:
         os.mkdir(os.path.join(os.getcwd(), name))
     except FileExistsError:
-        click.echo(
-            f'Project or module with name "{name}" already exists. Exiting.'
-        )
+        click.echo(f'Project or module with name "{name}" already exists. Exiting.')
         exit(0)
 
     os.makedirs(os.path.join(os.getcwd(), name, "ext"))
-    ext_is_package = open(
-        os.path.join(os.getcwd(), name, "ext", "__init__.py"), "w"
-    )
+    ext_is_package = open(os.path.join(os.getcwd(), name, "ext", "__init__.py"), "w")
     ext_is_package.close()
     os.makedirs(os.path.join(os.getcwd(), name, "blueprints"))
     blueprint_is_package = open(
@@ -78,15 +73,9 @@ def init(name: str):
     templates_and_dest = {
         "app.pyt": os.path.join(os.getcwd(), name, "app.py"),
         "views.pyt": os.path.join(os.getcwd(), name, "views.py"),
-        "index.htmlt": os.path.join(
-            os.getcwd(), name, "templates", "index.html"
-        ),
-        "configuration.pyt": os.path.join(
-            os.getcwd(), name, "ext", "configuration.py"
-        ),
-        "settings.tomlt": os.path.join(
-            os.getcwd(), "instance", "settings.toml"
-        ),
+        "index.htmlt": os.path.join(os.getcwd(), name, "templates", "index.html"),
+        "configuration.pyt": os.path.join(os.getcwd(), name, "ext", "configuration.py"),
+        "settings.tomlt": os.path.join(os.getcwd(), "instance", "settings.toml"),
         "manage.pyt": os.path.join(os.getcwd(), "manage.py"),
     }
 
@@ -98,12 +87,14 @@ def init(name: str):
     click.echo("Done!")
 
     # Requirements will help you do the basic startup of your virtualenv.
-    add_support_to("Flask==2.0.2")
-    add_support_to("dynaconf==3.1.7")
-    add_support_to("toml")
-    add_support_to(f"flaskstarter=={__version__}")
-
-    click.echo("If you do have other requirements, feel free to customize it.")
+    baserequirements = [
+        "Flask",
+        "dynaconf",
+        "toml",
+        f"flaskstarter=={__version__}",
+    ]
+    for requirement in baserequirements:
+        click.echo(f'Please, add "{requirement}" to the list of dependencies.')
 
     click.echo("Project created!")
 
@@ -111,6 +102,4 @@ def init(name: str):
 
 
 if __name__ == "__main__":
-    flaskstarter(
-        prog_name="flaskstarter"
-    )  # pylint: disable=unexpected-keyword-arg
+    flaskstarter(prog_name="flaskstarter")  # pylint: disable=unexpected-keyword-arg
